define((()=>(()=>{var e={758:(e,n,r)=>{r.p=document.querySelector("body").getAttribute("data-base-url")+"nbextensions/GiN",window.require&&window.require.config({map:{"*":{GiN:"nbextensions/GiN/index"}}}),e.exports={load_ipython_extension:function(){}}}},n={};function r(t){var i=n[t];if(void 0!==i)return i.exports;var o=n[t]={exports:{}};return e[t](o,o.exports,r),o.exports}return r.p="",r(758)})()));